*===================== PROGRAM: PQI09_FORMATS.SAS ===========================;
* Title:
*     Format Library for PREVENTION QUALITY INDICATOR PQI 09 Programs;
*
* Description:
*     FORMAT LIB FOR ALL AHRQ PREVENTION QUALITY INDICATOR 09, LOW BIRTH WEIGHT RATE
*     NOTE THAT THIS INDICATOR IS INCLUDED IN THE PEDIATRIC QUALITY
*     INDICATOR MODULE (PDI). 
*
*                   >>>  AHRQ QI ICD-10 VERSION 6.0.1 <<<
*	                  >>> VERSION DATE SEPT, 2016 <<< 
*============================================================================;
*PATHNAME specifies the location of the PQI09 folder which includes the
          Programs, Macros, and SASdata subfolders;
%LET PATHNAME=c:\Pathname;                        *<==USER MUST modify;

filename CONTROL "&PATHNAME.\PQI09\Programs\PQI09_ALL_CONTROL.SAS"; 

%INCLUDE CONTROL;


proc format library=LIBRARY;

 /* -------------------------------------------------------------- */
 /* --- FORMATS FOR STRATIFIERS ---------------------------------- */
 /* -------------------------------------------------------------- */

 /* --- FORMAT FOR SEX CATEGORY ---------------------------------- */
value SEXCAT
 1 = 'Male'
 2 = 'Female'
  ;

 /* --- FORMAT FOR AGE CATEGORY ---------------------------------- */
value PAGECAT
 1 = "<1"
 2 = "1 TO 2"
 3 = "3 TO 5"
 4 = "6 TO 12"
 5 = "13 TO 17"
 ;

 /* --- FORMAT FOR AGEDAY CATEGORY ------------------------------- */
value AGEDCAT
 0 = "NA"
 1 = "0 TO 28"
 2 = "29 TO 60"
 3 = "61 TO 90"
 4 = "91+"
 ;

 /* --- FORMAT FOR BIRTH WEIGHT CATEGORY ------------------------- */
value BWHTCAT
 0 = "NA"
 1 = "0 TO 499g"
 2 = "500 TO 749g"
 3 = "750 TO 999g"
 4 = "1000 TO 1249g"
 5 = "1250 TO 1499g"
 6 = "1500 TO 1749g"
 7 = "1750 TO 1999g"
 8 = "2000 TO 2499g"
 9 = "2500g or more"
 ;

 /* --- FORMAT FOR RACE CATEGORY --------------------------------- */
value RACECAT
 1 = 'White'
 2 = 'Black'
 3 = 'Hispanic'
 4 = 'Asian and NH/PI'
 5 = 'Amer Indian/AN'
 6 = 'Other'
  ;

 /* --- FORMAT FOR PAYER CATEGORY ---------------------------------- */
value PAYCAT
 1 = 'Medicare'
 2 = 'Medicaid'
 3 = 'Private'
 4 = 'Self Pay'
 5 = 'No Charge'
 6 = 'Other'
  ;

 /* --- FORMAT FOR POPULATION CATEGORY ----------------------------- */
value POPCAT
 1 = '0 to 4'
 2 = '5 to 9'
 3 = '10 to 14'
 4 = '15 to 17'
  ;

 /* ---   FORMAT FOR AGE STRATIFIERS ------------------------------ */

value AGEFMT
low - 4 = 1
 5 -  9 = 2
10 - 14 = 3
15 - 17 = 4
18 - 24 = 5
25 - 29 = 6
30 - 34 = 7
35 - 39 = 8
40 - 44 = 9
45 - 49 = 10
50 - 54 = 11
55 - 59 = 12
60 - 64 = 13
65 - 69 = 14
70 - 74 = 15
75 - 79 = 16
80 - 84 = 17
85 - high = 18;
 * -------------------------------------------------------------- ;
 * --- PDI DEFINING FORMATS ------------------------------------- ;
 * -------------------------------------------------------------- ;

 /* -------------------------------------------------------------- */
/* ---   FORMATS FOR DRG STRATIFIERS                          --- */
/* ---   MODULE 3. ASSIGNS ARRAY INDEX FOR DRG CATEGORIES     --- */
/* -------------------------------------------------------------- */
/* MS-DRG (V33) TO MODIFIED DRG */
value $DRGF2T
001 = 7701
002 = 7701
003 = 7799
004 = 7799
005 = 7702
006 = 7702
007 = 7703
008 = 7704
009 = 7705
010 = 7706
011 = 7799
012 = 7799
013 = 7799
014 = 7705
015 = 7705
016 = 7705
017 = 7705
020 = 0101
021 = 0101
022 = 0101
023 = 0102
024 = 0102
025 = 0103
026 = 0103
027 = 0103
028 = 0104
029 = 0104
030 = 0104
031 = 0105
032 = 0105
033 = 0105
034 = 0106
035 = 0106
036 = 0106
037 = 0107
038 = 0107
039 = 0107
040 = 0108
041 = 0108
042 = 0108
052 = 0109
053 = 0109
054 = 0110
055 = 0110
056 = 0111
057 = 0111
058 = 0112
059 = 0112
060 = 0112
061 = 0113
062 = 0113
063 = 0113
064 = 0114
065 = 0114
066 = 0114
067 = 0115
068 = 0115
069 = 0116
070 = 0117
071 = 0117
072 = 0117
073 = 0118
074 = 0118
075 = 0119
076 = 0119
077 = 0120
078 = 0120
079 = 0120
080 = 0121
081 = 0121
082 = 0122
083 = 0122
084 = 0122
085 = 0123
086 = 0123
087 = 0123
088 = 0124
089 = 0124
090 = 0124
091 = 0125
092 = 0125
093 = 0125
094 = 0126
095 = 0126
096 = 0126
097 = 0127
098 = 0127
099 = 0127
100 = 0128
101 = 0128
102 = 0129
103 = 0129
113 = 0201
114 = 0201
115 = 0202
116 = 0203
117 = 0203
121 = 0204
122 = 0204
123 = 0205
124 = 0206
125 = 0206
129 = 0301
130 = 0301
131 = 0301
132 = 0301
133 = 0302
134 = 0302
135 = 0303
136 = 0303
137 = 0304
138 = 0304
139 = 0305
146 = 0306
147 = 0306
148 = 0306
149 = 0307
150 = 0308
151 = 0308
152 = 0309
153 = 0309
154 = 0310
155 = 0310
156 = 0310
157 = 0311
158 = 0311
159 = 0311
163 = 0401
164 = 0401
165 = 0401
166 = 0402
167 = 0402
168 = 0402
175 = 0403
176 = 0403
177 = 0404
178 = 0404
179 = 0404
180 = 0405
181 = 0405
182 = 0405
183 = 0406
184 = 0406
185 = 0406
186 = 0407
187 = 0407
188 = 0407
189 = 0408
190 = 0409
191 = 0409
192 = 0409
193 = 0410
194 = 0410
195 = 0410
196 = 0411
197 = 0411
198 = 0411
199 = 0412
200 = 0412
201 = 0412
202 = 0413
203 = 0413
204 = 0414
205 = 0415
206 = 0415
207 = 0416
208 = 0416
215 = 0501
216 = 0503
217 = 0503
218 = 0503
219 = 0503
220 = 0503
221 = 0503
222 = 0504
223 = 0504
224 = 0504
225 = 0504
226 = 0504
227 = 0504
228 = 0505
229 = 0505
230 = 0505
231 = 0506
232 = 0506
233 = 0507
234 = 0507
235 = 0507
236 = 0507
237 = 0508
238 = 0508
239 = 0509
240 = 0509
241 = 0509
242 = 0510
243 = 0510
244 = 0510
245 = 0510
246 = 0511
247 = 0511
248 = 0502
249 = 0502
250 = 0513
251 = 0513
252 = 0514
253 = 0514
254 = 0514
255 = 0515
256 = 0515
257 = 0515
258 = 0516
259 = 0516
260 = 0517
261 = 0517
262 = 0517
263 = 0518
264 = 0519
265 = 0510
266 = 0540
267 = 0540
268 = 0541
269 = 0541
270 = 0542
271 = 0542
272 = 0542
273 = 0543
274 = 0543
280 = 0520
281 = 0520
282 = 0520
283 = 0521
284 = 0521
285 = 0521
286 = 0522
287 = 0522
288 = 0523
289 = 0523
290 = 0523
291 = 0524
292 = 0524
293 = 0524
294 = 0525
295 = 0525
296 = 0526
297 = 0526
298 = 0526
299 = 0527
300 = 0527
301 = 0527
302 = 0528
303 = 0528
304 = 0529
305 = 0529
306 = 0530
307 = 0530
308 = 0531
309 = 0531
310 = 0531
311 = 0532
312 = 0533
313 = 0534
314 = 0535
315 = 0535
316 = 0535
326 = 0601
327 = 0601
328 = 0601
329 = 0602
330 = 0602
331 = 0602
332 = 0603
333 = 0603
334 = 0603
335 = 0604
336 = 0604
337 = 0604
338 = 0605
339 = 0605
340 = 0605
341 = 0606
342 = 0606
343 = 0606
344 = 0607
345 = 0607
346 = 0607
347 = 0608
348 = 0608
349 = 0608
350 = 0609
351 = 0609
352 = 0609
353 = 0610
354 = 0610
355 = 0610
356 = 0611
357 = 0611
358 = 0611
368 = 0612
369 = 0612
370 = 0612
371 = 0613
372 = 0613
373 = 0613
374 = 0614
375 = 0614
376 = 0614
377 = 0615
378 = 0615
379 = 0615
380 = 0616
381 = 0616
382 = 0616
383 = 0617
384 = 0617
385 = 0618
386 = 0618
387 = 0618
388 = 0619
389 = 0619
390 = 0619
391 = 0620
392 = 0620
393 = 0621
394 = 0621
395 = 0621
405 = 0701
406 = 0701
407 = 0701
408 = 0702
409 = 0702
410 = 0702
411 = 0703
412 = 0703
413 = 0703
414 = 0704
415 = 0704
416 = 0704
417 = 0705
418 = 0705
419 = 0705
420 = 0706
421 = 0706
422 = 0706
423 = 0707
424 = 0707
425 = 0707
432 = 0708
433 = 0708
434 = 0708
435 = 0709
436 = 0709
437 = 0709
438 = 0710
439 = 0710
440 = 0710
441 = 0711
442 = 0711
443 = 0711
444 = 0712
445 = 0712
446 = 0712
453 = 0801
454 = 0801
455 = 0801
456 = 0802
457 = 0802
458 = 0802
459 = 0803
460 = 0803
461 = 0804
462 = 0804
463 = 0805
464 = 0805
465 = 0805
466 = 0806
467 = 0806
468 = 0806
469 = 0807
470 = 0807
471 = 0808
472 = 0808
473 = 0808
474 = 0809
475 = 0809
476 = 0809
477 = 0810
478 = 0810
479 = 0810
480 = 0811
481 = 0811
482 = 0811
483 = 0812
484 = 0812
485 = 0813
486 = 0813
487 = 0813
488 = 0814
489 = 0814
490 = 0815
491 = 0815
492 = 0816
493 = 0816
494 = 0816
495 = 0817
496 = 0817
497 = 0817
498 = 0818
499 = 0818
500 = 0819
501 = 0819
502 = 0819
503 = 0820
504 = 0820
505 = 0820
506 = 0821
507 = 0822
508 = 0822
509 = 0823
510 = 0824
511 = 0824
512 = 0824
513 = 0825
514 = 0825
515 = 0826
516 = 0826
517 = 0826
518 = 0815
519 = 0815
520 = 0815
533 = 0827
534 = 0827
535 = 0828
536 = 0828
537 = 0829
538 = 0829
539 = 0830
540 = 0830
541 = 0830
542 = 0831
543 = 0831
544 = 0831
545 = 0832
546 = 0832
547 = 0832
548 = 0833
549 = 0833
550 = 0833
551 = 0834
552 = 0834
553 = 0835
554 = 0835
555 = 0836
556 = 0836
557 = 0837
558 = 0837
559 = 0838
560 = 0838
561 = 0838
562 = 0839
563 = 0839
564 = 0840
565 = 0840
566 = 0840
570 = 0901
571 = 0901
572 = 0901
573 = 0901
574 = 0901
575 = 0901
576 = 0902
577 = 0902
578 = 0902
579 = 0903
580 = 0903
581 = 0903
582 = 0904
583 = 0904
584 = 0905
585 = 0905
592 = 0906
593 = 0906
594 = 0906
595 = 0907
596 = 0907
597 = 0908
598 = 0908
599 = 0908
600 = 0909
601 = 0909
602 = 0910
603 = 0910
604 = 0911
605 = 0911
606 = 0912
607 = 0912
614 = 1001
615 = 1001
616 = 1002
617 = 1002
618 = 1002
619 = 1003
620 = 1003
621 = 1003
622 = 1004
623 = 1004
624 = 1004
625 = 1005
626 = 1005
627 = 1005
628 = 1006
629 = 1006
630 = 1006
637 = 1007
638 = 1007
639 = 1007
640 = 1008
641 = 1008
642 = 1009
643 = 1010
644 = 1010
645 = 1010
652 = 1101
653 = 1102
654 = 1102
655 = 1102
656 = 1103
657 = 1103
658 = 1103
659 = 1104
660 = 1104
661 = 1104
662 = 1105
663 = 1105
664 = 1105
665 = 1106
666 = 1106
667 = 1106
668 = 1107
669 = 1107
670 = 1107
671 = 1108
672 = 1108
673 = 1109
674 = 1109
675 = 1109
682 = 1110
683 = 1110
684 = 1110
685 = 1111
686 = 1112
687 = 1112
688 = 1112
689 = 1113
690 = 1113
691 = 1114
692 = 1114
693 = 1115
694 = 1115
695 = 1116
696 = 1116
697 = 1117
698 = 1118
699 = 1118
700 = 1118
707 = 1201
708 = 1201
709 = 1202
710 = 1202
711 = 1203
712 = 1203
713 = 1204
714 = 1204
715 = 1205
716 = 1205
717 = 1206
718 = 1206
722 = 1207
723 = 1207
724 = 1207
725 = 1208
726 = 1208
727 = 1209
728 = 1209
729 = 1210
730 = 1210
734 = 1301
735 = 1301
736 = 1302
737 = 1302
738 = 1302
739 = 1303
740 = 1303
741 = 1303
742 = 1304
743 = 1304
744 = 1305
745 = 1305
746 = 1306
747 = 1306
748 = 1307
749 = 1308
750 = 1308
754 = 1309
755 = 1309
756 = 1309
757 = 1310
758 = 1310
759 = 1310
760 = 1311
761 = 1311
765 = 1401
766 = 1401
767 = 1402
768 = 1402
769 = 1403
770 = 1404
774 = 1405
775 = 1405
776 = 1406
777 = 1407
778 = 1408
779 = 1409
780 = 1410
781 = 1411
782 = 1412
789 = 1501
790 = 1502
791 = 1503
792 = 1504
793 = 1505
794 = 1506
795 = 1507
799 = 1601
800 = 1601
801 = 1601
802 = 1602
803 = 1602
804 = 1602
808 = 1603
809 = 1603
810 = 1603
811 = 1604
812 = 1604
813 = 1605
814 = 1606
815 = 1606
816 = 1606
820 = 1707
821 = 1707
822 = 1707
823 = 1708
824 = 1708
825 = 1708
826 = 1709
827 = 1709
828 = 1709
829 = 1710
830 = 1710
834 = 1711
835 = 1711
836 = 1711
837 = 1712
838 = 1712
839 = 1712
840 = 1713
841 = 1713
842 = 1713
843 = 1714
844 = 1714
845 = 1714
846 = 1715
847 = 1715
848 = 1715
849 = 1716
853 = 1801
854 = 1801
855 = 1801
856 = 1802
857 = 1802
858 = 1802
862 = 1803
863 = 1803
864 = 1804
865 = 1805
866 = 1805
867 = 1806
868 = 1806
869 = 1806
870 = 1807
871 = 1808
872 = 1808
876 = 1909
880 = 1910
881 = 1911
882 = 1912
883 = 1913
884 = 1914
885 = 1915
886 = 1916
887 = 1917
894 = 2018
895 = 2019
896 = 2020
897 = 2020
901 = 2101
902 = 2101
903 = 2101
904 = 2102
905 = 2102
906 = 2103
907 = 2104
908 = 2104
909 = 2104
913 = 2105
914 = 2105
915 = 2106
916 = 2106
917 = 2107
918 = 2107
919 = 2108
920 = 2108
921 = 2108
922 = 2109
923 = 2109
927 = 2210
928 = 2201
929 = 2201
933 = 2212
934 = 2213
935 = 2214
939 = 2301
940 = 2301
941 = 2301
945 = 2302
946 = 2302
947 = 2303
948 = 2303
949 = 2304
950 = 2304
951 = 2305
955 = 2406
956 = 2407
957 = 2408
958 = 2408
959 = 2408
963 = 2409
964 = 2409
965 = 2409
969 = 2501
970 = 2501
974 = 2502
975 = 2502
976 = 2502
977 = 2503
981 = 8899
982 = 8899
983 = 8899
984 = 8899
985 = 8899
986 = 8899
987 = 8899
988 = 8899
989 = 8899
998 = 8898
999 = 8898
other = 9999;

 /* MS-DRG (V33) TO MDC */;

value MDCF2T
001 = 77
002 = 77
003 = 77
004 = 77
005 = 77
006 = 77
007 = 77
008 = 77
009 = 77
010 = 77
011 = 77
012 = 77
013 = 77
014 = 77   
015 = 77  
016 = 77
017 = 77
020 = 01
021 = 01
022 = 01
023 = 01
024 = 01
025 = 01
026 = 01
027 = 01
028 = 01
029 = 01
030 = 01
031 = 01
032 = 01
033 = 01
034 = 01
035 = 01
036 = 01
037 = 01
038 = 01
039 = 01
040 = 01
041 = 01
042 = 01
052 = 01
053 = 01
054 = 01
055 = 01
056 = 01
057 = 01
058 = 01
059 = 01
060 = 01
061 = 01
062 = 01
063 = 01
064 = 01
065 = 01
066 = 01
067 = 01
068 = 01
069 = 01
070 = 01
071 = 01
072 = 01
073 = 01
074 = 01
075 = 01
076 = 01
077 = 01
078 = 01
079 = 01
080 = 01
081 = 01
082 = 01
083 = 01
084 = 01
085 = 01
086 = 01
087 = 01
088 = 01
089 = 01
090 = 01
091 = 01
092 = 01
093 = 01
094 = 01
095 = 01
096 = 01
097 = 01
098 = 01
099 = 01
100 = 01
101 = 01
102 = 01
103 = 01
113 = 02
114 = 02
115 = 02
116 = 02
117 = 02
121 = 02
122 = 02
123 = 02
124 = 02
125 = 02
129 = 03
130 = 03
131 = 03
132 = 03
133 = 03
134 = 03
135 = 03
136 = 03
137 = 03
138 = 03
139 = 03
146 = 03
147 = 03
148 = 03
149 = 03
150 = 03
151 = 03
152 = 03
153 = 03
154 = 03
155 = 03
156 = 03
157 = 03
158 = 03
159 = 03
163 = 04
164 = 04
165 = 04
166 = 04
167 = 04
168 = 04
175 = 04
176 = 04
177 = 04
178 = 04
179 = 04
180 = 04
181 = 04
182 = 04
183 = 04
184 = 04
185 = 04
186 = 04
187 = 04
188 = 04
189 = 04
190 = 04
191 = 04
192 = 04
193 = 04
194 = 04
195 = 04
196 = 04
197 = 04
198 = 04
199 = 04
200 = 04
201 = 04
202 = 04
203 = 04
204 = 04
205 = 04
206 = 04
207 = 04
208 = 04
215 = 05
216 = 05
217 = 05
218 = 05
219 = 05
220 = 05
221 = 05
222 = 05
223 = 05
224 = 05
225 = 05
226 = 05
227 = 05
228 = 05
229 = 05
230 = 05
231 = 05
232 = 05
233 = 05
234 = 05
235 = 05
236 = 05
237 = 05
238 = 05
239 = 05
240 = 05
241 = 05
242 = 05
243 = 05
244 = 05
245 = 05
246 = 05
247 = 05
248 = 05
249 = 05
250 = 05
251 = 05
252 = 05
253 = 05
254 = 05
255 = 05
256 = 05
257 = 05
258 = 05
259 = 05
260 = 05
261 = 05
262 = 05
263 = 05
264 = 05
265 = 05
266 = 05
267 = 05
280 = 05
281 = 05
282 = 05
283 = 05
284 = 05
285 = 05
286 = 05
287 = 05
288 = 05
289 = 05
290 = 05
291 = 05
292 = 05
293 = 05
294 = 05
295 = 05
296 = 05
297 = 05
298 = 05
299 = 05
300 = 05
301 = 05
302 = 05
303 = 05
304 = 05
305 = 05
306 = 05
307 = 05
308 = 05
309 = 05
310 = 05
311 = 05
312 = 05
313 = 05
314 = 05
315 = 05
316 = 05
326 = 06
327 = 06
328 = 06
329 = 06
330 = 06
331 = 06
332 = 06
333 = 06
334 = 06
335 = 06
336 = 06
337 = 06
338 = 06
339 = 06
340 = 06
341 = 06
342 = 06
343 = 06
344 = 06
345 = 06
346 = 06
347 = 06
348 = 06
349 = 06
350 = 06
351 = 06
352 = 06
353 = 06
354 = 06
355 = 06
356 = 06
357 = 06
358 = 06
368 = 06
369 = 06
370 = 06
371 = 06
372 = 06
373 = 06
374 = 06
375 = 06
376 = 06
377 = 06
378 = 06
379 = 06
380 = 06
381 = 06
382 = 06
383 = 06
384 = 06
385 = 06
386 = 06
387 = 06
388 = 06
389 = 06
390 = 06
391 = 06
392 = 06
393 = 06
394 = 06
395 = 06
405 = 07
406 = 07
407 = 07
408 = 07
409 = 07
410 = 07
411 = 07
412 = 07
413 = 07
414 = 07
415 = 07
416 = 07
417 = 07
418 = 07
419 = 07
420 = 07
421 = 07
422 = 07
423 = 07
424 = 07
425 = 07
432 = 07
433 = 07
434 = 07
435 = 07
436 = 07
437 = 07
438 = 07
439 = 07
440 = 07
441 = 07
442 = 07
443 = 07
444 = 07
445 = 07
446 = 07
453 = 08
454 = 08
455 = 08
456 = 08
457 = 08
458 = 08
459 = 08
460 = 08
461 = 08
462 = 08
463 = 08
464 = 08
465 = 08
466 = 08
467 = 08
468 = 08
469 = 08
470 = 08
471 = 08
472 = 08
473 = 08
474 = 08
475 = 08
476 = 08
477 = 08
478 = 08
479 = 08
480 = 08
481 = 08
482 = 08
483 = 08
484 = 08
485 = 08
486 = 08
487 = 08
488 = 08
489 = 08
490 = 08
491 = 08
492 = 08
493 = 08
494 = 08
495 = 08
496 = 08
497 = 08
498 = 08
499 = 08
500 = 08
501 = 08
502 = 08
503 = 08
504 = 08
505 = 08
506 = 08
507 = 08
508 = 08
509 = 08
510 = 08
511 = 08
512 = 08
513 = 08
514 = 08
515 = 08
516 = 08
517 = 08
518 = 08
519 = 08
520 = 08
533 = 08
534 = 08
535 = 08
536 = 08
537 = 08
538 = 08
539 = 08
540 = 08
541 = 08
542 = 08
543 = 08
544 = 08
545 = 08
546 = 08
547 = 08
548 = 08
549 = 08
550 = 08
551 = 08
552 = 08
553 = 08
554 = 08
555 = 08
556 = 08
557 = 08
558 = 08
559 = 08
560 = 08
561 = 08
562 = 08
563 = 08
564 = 08
565 = 08
566 = 08
570 = 09
571 = 09
572 = 09
573 = 09
574 = 09
575 = 09
576 = 09
577 = 09
578 = 09
579 = 09
580 = 09
581 = 09
582 = 09
583 = 09
584 = 09
585 = 09
592 = 09
593 = 09
594 = 09
595 = 09
596 = 09
597 = 09
598 = 09
599 = 09
600 = 09
601 = 09
602 = 09
603 = 09
604 = 09
605 = 09
606 = 09
607 = 09
614 = 10
615 = 10
616 = 10
617 = 10
618 = 10
619 = 10
620 = 10
621 = 10
622 = 10
623 = 10
624 = 10
625 = 10
626 = 10
627 = 10
628 = 10
629 = 10
630 = 10
637 = 10
638 = 10
639 = 10
640 = 10
641 = 10
642 = 10
643 = 10
644 = 10
645 = 10
652 = 11
653 = 11
654 = 11
655 = 11
656 = 11
657 = 11
658 = 11
659 = 11
660 = 11
661 = 11
662 = 11
663 = 11
664 = 11
665 = 11
666 = 11
667 = 11
668 = 11
669 = 11
670 = 11
671 = 11
672 = 11
673 = 11
674 = 11
675 = 11
682 = 11
683 = 11
684 = 11
685 = 11
686 = 11
687 = 11
688 = 11
689 = 11
690 = 11
691 = 11
692 = 11
693 = 11
694 = 11
695 = 11
696 = 11
697 = 11
698 = 11
699 = 11
700 = 11
707 = 12
708 = 12
709 = 12
710 = 12
711 = 12
712 = 12
713 = 12
714 = 12
715 = 12
716 = 12
717 = 12
718 = 12
722 = 12
723 = 12
724 = 12
725 = 12
726 = 12
727 = 12
728 = 12
729 = 12
730 = 12
734 = 13
735 = 13
736 = 13
737 = 13
738 = 13
739 = 13
740 = 13
741 = 13
742 = 13
743 = 13
744 = 13
745 = 13
746 = 13
747 = 13
748 = 13
749 = 13
750 = 13
754 = 13
755 = 13
756 = 13
757 = 13
758 = 13
759 = 13
760 = 13
761 = 13
765 = 14
766 = 14
767 = 14
768 = 14
769 = 14
770 = 14
774 = 14
775 = 14
776 = 14
777 = 14
778 = 14
779 = 14
780 = 14
781 = 14
782 = 14
789 = 15
790 = 15
791 = 15
792 = 15
793 = 15
794 = 15
795 = 15
799 = 16
800 = 16
801 = 16
802 = 16
803 = 16
804 = 16
808 = 16
809 = 16
810 = 16
811 = 16
812 = 16
813 = 16
814 = 16
815 = 16
816 = 16
820 = 17
821 = 17
822 = 17
823 = 17
824 = 17
825 = 17
826 = 17
827 = 17
828 = 17
829 = 17
830 = 17
834 = 17
835 = 17
836 = 17
837 = 17
838 = 17
839 = 17
840 = 17
841 = 17
842 = 17
843 = 17
844 = 17
845 = 17
846 = 17
847 = 17
848 = 17
849 = 17
853 = 18
854 = 18
855 = 18
856 = 18
857 = 18
858 = 18
862 = 18
863 = 18
864 = 18
865 = 18
866 = 18
867 = 18
868 = 18
869 = 18
870 = 18
871 = 18
872 = 18
876 = 19
880 = 19
881 = 19
882 = 19
883 = 19
884 = 19
885 = 19
886 = 19
887 = 19
894 = 20
895 = 20
896 = 20
897 = 20
901 = 21
902 = 21
903 = 21
904 = 21
905 = 21
906 = 21
907 = 21
908 = 21
909 = 21
913 = 21
914 = 21
915 = 21
916 = 21
917 = 21
918 = 21
919 = 21
920 = 21
921 = 21
922 = 21
923 = 21
927 = 22
928 = 22
929 = 22
933 = 22
934 = 22
935 = 22
939 = 23
940 = 23
941 = 23
945 = 23
946 = 23
947 = 23
948 = 23
949 = 23
950 = 23
951 = 23
955 = 24
956 = 24
957 = 24
958 = 24
959 = 24
963 = 24
964 = 24
965 = 24
969 = 25
970 = 25
974 = 25
975 = 25
976 = 25
977 = 25
981 = 88
982 = 88
983 = 88
984 = 88
985 = 88
986 = 88
987 = 88
988 = 88
989 = 88
998 = 88
999 = 88
OTHER  = 99 ;

 /* --------------------------------------------------------------- */
 /* ---   POVERTY DECILE                                          - */
 /* --------------------------------------------------------------- */

value $POVCAT
"01001" = 3
"01003" = 4
"01005" = 10
"01007" = 9
"01009" = 6
"01011" = 10
"01013" = 10
"01015" = 10
"01017" = 10
"01019" = 9
"01021" = 9
"01023" = 9
"01025" = 10
"01027" = 9
"01029" = 8
"01031" = 9
"01033" = 9
"01035" = 10
"01037" = 8
"01039" = 9
"01041" = 9
"01043" = 9
"01045" = 8
"01047" = 10
"01049" = 9
"01051" = 4
"01053" = 10
"01055" = 8
"01057" = 10
"01059" = 9
"01061" = 9
"01063" = 10
"01065" = 10
"01067" = 8
"01069" = 8
"01071" = 9
"01073" = 8
"01075" = 9
"01077" = 7
"01079" = 8
"01081" = 9
"01083" = 4
"01085" = 10
"01087" = 10
"01089" = 4
"01091" = 10
"01093" = 9
"01095" = 9
"01097" = 9
"01099" = 10
"01101" = 9
"01103" = 4
"01105" = 10
"01107" = 10
"01109" = 10
"01111" = 10
"01113" = 10
"01115" = 4
"01117" = 2
"01119" = 10
"01121" = 10
"01123" = 8
"01125" = 8
"01127" = 10
"01129" = 9
"01131" = 10
"01133" = 9
"02013" = 7
"02016" = 2
"02020" = 2
"02050" = 10
"02060" = 2
"02068" = 1
"02070" = 9
"02090" = 2
"02100" = 3
"02105" = 9
"02110" = 1
"02122" = 2
"02130" = 2
"02150" = 2
"02164" = 8
"02170" = 3
"02180" = 10
"02185" = 3
"02188" = 9
"02195" = 2
"02198" = 7
"02220" = 2
"02230" = 1
"02240" = 4
"02261" = 2
"02270" = 10
"02275" = 4
"02282" = 5
"02290" = 10
"04001" = 10
"04003" = 8
"04005" = 10
"04007" = 9
"04009" = 9
"04011" = 4
"04012" = 10
"04013" = 6
"04015" = 8
"04017" = 10
"04019" = 8
"04021" = 5
"04023" = 10
"04025" = 8
"04027" = 9
"05001" = 8
"05003" = 9
"05005" = 6
"05007" = 2
"05009" = 6
"05011" = 10
"05013" = 6
"05015" = 6
"05017" = 10
"05019" = 10
"05021" = 8
"05023" = 8
"05025" = 6
"05027" = 10
"05029" = 8
"05031" = 9
"05033" = 6
"05035" = 10
"05037" = 9
"05039" = 9
"05041" = 10
"05043" = 9
"05045" = 5
"05047" = 7
"05049" = 8
"05051" = 9
"05053" = 3
"05055" = 7
"05057" = 10
"05059" = 5
"05061" = 9
"05063" = 8
"05065" = 8
"05067" = 10
"05069" = 10
"05071" = 10
"05073" = 10
"05075" = 10
"05077" = 10
"05079" = 10
"05081" = 8
"05083" = 7
"05085" = 4
"05087" = 9
"05089" = 9
"05091" = 9
"05093" = 10
"05095" = 10
"05097" = 10
"05099" = 10
"05101" = 10
"05103" = 9
"05105" = 7
"05107" = 10
"05109" = 9
"05111" = 10
"05113" = 10
"05115" = 8
"05117" = 8
"05119" = 7
"05121" = 9
"05123" = 10
"05125" = 2
"05127" = 10
"05129" = 10
"05131" = 9
"05133" = 10
"05135" = 10
"05137" = 10
"05139" = 9
"05141" = 9
"05143" = 9
"05145" = 6
"05147" = 10
"05149" = 9
"06001" = 4
"06003" = 7
"06005" = 4
"06007" = 9
"06009" = 3
"06011" = 5
"06013" = 2
"06015" = 10
"06017" = 2
"06019" = 10
"06021" = 7
"06023" = 8
"06025" = 10
"06027" = 4
"06029" = 9
"06031" = 10
"06033" = 9
"06035" = 7
"06037" = 7
"06039" = 9
"06041" = 2
"06043" = 5
"06045" = 9
"06047" = 10
"06049" = 10
"06051" = 3
"06053" = 7
"06055" = 2
"06057" = 3
"06059" = 3
"06061" = 2
"06063" = 5
"06065" = 6
"06067" = 6
"06069" = 4
"06071" = 8
"06073" = 5
"06075" = 4
"06077" = 8
"06079" = 5
"06081" = 1
"06083" = 8
"06085" = 2
"06087" = 5
"06089" = 8
"06091" = 4
"06093" = 9
"06095" = 3
"06097" = 4
"06099" = 9
"06101" = 7
"06103" = 9
"06105" = 8
"06107" = 10
"06109" = 5
"06111" = 3
"06113" = 6
"06115" = 9
"08001" = 4
"08003" = 9
"08005" = 3
"08007" = 4
"08009" = 7
"08011" = 10
"08013" = 4
"08014" = 1
"08015" = 4
"08017" = 3
"08019" = 2
"08021" = 9
"08023" = 10
"08025" = 10
"08027" = 5
"08029" = 6
"08031" = 9
"08033" = 4
"08035" = 1
"08037" = 2
"08039" = 1
"08041" = 4
"08043" = 6
"08045" = 2
"08047" = 1
"08049" = 2
"08051" = 5
"08053" = 2
"08055" = 10
"08057" = 5
"08059" = 2
"08061" = 4
"08063" = 4
"08065" = 5
"08067" = 3
"08069" = 4
"08071" = 8
"08073" = 8
"08075" = 6
"08077" = 5
"08079" = 3
"08081" = 2
"08083" = 7
"08085" = 5
"08087" = 5
"08089" = 9
"08091" = 2
"08093" = 2
"08095" = 3
"08097" = 1
"08099" = 10
"08101" = 9
"08103" = 2
"08105" = 7
"08107" = 1
"08109" = 10
"08111" = 6
"08113" = 2
"08115" = 4
"08117" = 2
"08119" = 2
"08121" = 4
"08123" = 5
"08125" = 4
"09001" = 2
"09003" = 3
"09005" = 1
"09007" = 1
"09009" = 3
"09011" = 2
"09013" = 1
"09015" = 3
"10001" = 3
"10003" = 3
"10005" = 4
"11001" = 8
"12001" = 10
"12003" = 7
"12005" = 5
"12007" = 9
"12009" = 4
"12011" = 5
"12013" = 10
"12015" = 4
"12017" = 7
"12019" = 3
"12021" = 6
"12023" = 9
"12027" = 10
"12029" = 10
"12031" = 6
"12033" = 9
"12035" = 6
"12037" = 10
"12039" = 10
"12041" = 9
"12043" = 9
"12045" = 9
"12047" = 10
"12049" = 10
"12051" = 10
"12053" = 5
"12055" = 9
"12057" = 6
"12059" = 10
"12061" = 5
"12063" = 8
"12065" = 8
"12067" = 10
"12069" = 4
"12071" = 7
"12073" = 10
"12075" = 10
"12077" = 10
"12079" = 10
"12081" = 5
"12083" = 9
"12085" = 3
"12086" = 9
"12087" = 4
"12089" = 3
"12091" = 4
"12093" = 10
"12095" = 6
"12097" = 6
"12099" = 5
"12101" = 5
"12103" = 5
"12105" = 7
"12107" = 10
"12109" = 3
"12111" = 7
"12113" = 4
"12115" = 4
"12117" = 3
"12119" = 4
"12121" = 9
"12123" = 9
"12125" = 10
"12127" = 6
"12129" = 4
"12131" = 6
"12133" = 9
"13001" = 10
"13003" = 10
"13005" = 10
"13007" = 10
"13009" = 10
"13011" = 6
"13013" = 3
"13015" = 5
"13017" = 10
"13019" = 9
"13021" = 10
"13023" = 9
"13025" = 10
"13027" = 10
"13029" = 3
"13031" = 10
"13033" = 10
"13035" = 6
"13037" = 10
"13039" = 6
"13043" = 10
"13045" = 8
"13047" = 5
"13049" = 10
"13051" = 9
"13053" = 8
"13055" = 9
"13057" = 2
"13059" = 10
"13061" = 10
"13063" = 10
"13065" = 10
"13067" = 4
"13069" = 10
"13071" = 10
"13073" = 2
"13075" = 10
"13077" = 3
"13079" = 8
"13081" = 10
"13083" = 6
"13085" = 4
"13087" = 10
"13089" = 9
"13091" = 10
"13093" = 10
"13095" = 10
"13097" = 4
"13099" = 10
"13101" = 10
"13103" = 2
"13105" = 10
"13107" = 10
"13109" = 10
"13111" = 8
"13113" = 1
"13115" = 9
"13117" = 1
"13119" = 8
"13121" = 8
"13123" = 6
"13125" = 8
"13127" = 8
"13129" = 8
"13131" = 10
"13133" = 10
"13135" = 4
"13137" = 7
"13139" = 8
"13141" = 10
"13143" = 9
"13145" = 2
"13147" = 10
"13149" = 9
"13151" = 2
"13153" = 4
"13155" = 10
"13157" = 6
"13159" = 8
"13161" = 10
"13163" = 10
"13165" = 10
"13167" = 10
"13169" = 3
"13171" = 8
"13173" = 10
"13175" = 9
"13177" = 2
"13179" = 10
"13181" = 9
"13183" = 9
"13185" = 10
"13187" = 6
"13189" = 9
"13191" = 8
"13193" = 10
"13195" = 7
"13197" = 10
"13199" = 9
"13201" = 10
"13205" = 10
"13207" = 5
"13209" = 10
"13211" = 6
"13213" = 9
"13215" = 9
"13217" = 5
"13219" = 1
"13221" = 6
"13223" = 2
"13225" = 10
"13227" = 4
"13229" = 8
"13231" = 4
"13233" = 10
"13235" = 9
"13237" = 8
"13239" = 10
"13241" = 8
"13243" = 10
"13245" = 10
"13247" = 5
"13249" = 7
"13251" = 10
"13253" = 10
"13255" = 10
"13257" = 10
"13259" = 10
"13261" = 10
"13263" = 9
"13265" = 10
"13267" = 10
"13269" = 10
"13271" = 10
"13273" = 10
"13275" = 10
"13277" = 10
"13279" = 10
"13281" = 5
"13283" = 10
"13285" = 9
"13287" = 10
"13289" = 10
"13291" = 9
"13293" = 9
"13295" = 8
"13297" = 5
"13299" = 10
"13301" = 10
"13303" = 10
"13305" = 10
"13307" = 10
"13309" = 10
"13311" = 7
"13313" = 9
"13315" = 10
"13317" = 10
"13319" = 9
"13321" = 9
"15001" = 8
"15003" = 2
"15005" = 1
"15007" = 3
"15009" = 3
"16001" = 4
"16003" = 6
"16005" = 6
"16007" = 6
"16009" = 7
"16011" = 6
"16013" = 2
"16015" = 5
"16017" = 7
"16019" = 4
"16021" = 7
"16023" = 6
"16025" = 3
"16027" = 9
"16029" = 3
"16031" = 6
"16033" = 8
"16035" = 5
"16037" = 5
"16039" = 6
"16041" = 2
"16043" = 6
"16045" = 7
"16047" = 6
"16049" = 8
"16051" = 3
"16053" = 9
"16055" = 5
"16057" = 7
"16059" = 9
"16061" = 8
"16063" = 4
"16065" = 10
"16067" = 6
"16069" = 4
"16071" = 4
"16073" = 10
"16075" = 7
"16077" = 6
"16079" = 9
"16081" = 3
"16083" = 6
"16085" = 4
"16087" = 7
"17001" = 4
"17003" = 10
"17005" = 4
"17007" = 3
"17009" = 5
"17011" = 3
"17013" = 3
"17015" = 4
"17017" = 4
"17019" = 9
"17021" = 5
"17023" = 3
"17025" = 5
"17027" = 2
"17029" = 8
"17031" = 7
"17033" = 5
"17035" = 3
"17037" = 5
"17039" = 3
"17041" = 3
"17043" = 1
"17045" = 5
"17047" = 3
"17049" = 2
"17051" = 6
"17053" = 3
"17055" = 9
"17057" = 5
"17059" = 8
"17061" = 5
"17063" = 1
"17065" = 5
"17067" = 4
"17069" = 9
"17071" = 3
"17073" = 3
"17075" = 3
"17077" = 10
"17079" = 3
"17081" = 7
"17083" = 2
"17085" = 2
"17087" = 5
"17089" = 3
"17091" = 5
"17093" = 1
"17095" = 6
"17097" = 2
"17099" = 4
"17101" = 7
"17103" = 3
"17105" = 3
"17107" = 3
"17109" = 10
"17111" = 1
"17113" = 3
"17115" = 8
"17117" = 4
"17119" = 5
"17121" = 6
"17123" = 3
"17125" = 5
"17127" = 6
"17129" = 2
"17131" = 3
"17133" = 1
"17135" = 5
"17137" = 5
"17139" = 2
"17141" = 3
"17143" = 5
"17145" = 7
"17147" = 1
"17149" = 7
"17151" = 8
"17153" = 9
"17155" = 1
"17157" = 4
"17159" = 5
"17161" = 4
"17163" = 6
"17165" = 9
"17167" = 4
"17169" = 3
"17171" = 2
"17173" = 3
"17175" = 2
"17177" = 4
"17179" = 2
"17181" = 8
"17183" = 9
"17185" = 5
"17187" = 4
"17189" = 1
"17191" = 5
"17193" = 7
"17195" = 3
"17197" = 2
"17199" = 6
"17201" = 7
"17203" = 1
"18001" = 7
"18003" = 4
"18005" = 4
"18007" = 3
"18009" = 6
"18011" = 1
"18013" = 4
"18015" = 2
"18017" = 6
"18019" = 4
"18021" = 4
"18023" = 4
"18025" = 7
"18027" = 5
"18029" = 2
"18031" = 4
"18033" = 2
"18035" = 10
"18037" = 2
"18039" = 7
"18041" = 7
"18043" = 4
"18045" = 4
"18047" = 3
"18049" = 4
"18051" = 3
"18053" = 9
"18055" = 4
"18057" = 1
"18059" = 2
"18061" = 3
"18063" = 1
"18065" = 6
"18067" = 6
"18069" = 3
"18071" = 4
"18073" = 2
"18075" = 6
"18077" = 6
"18079" = 5
"18081" = 2
"18083" = 7
"18085" = 4
"18087" = 6
"18089" = 8
"18091" = 6
"18093" = 5
"18095" = 8
"18097" = 9
"18099" = 4
"18101" = 4
"18103" = 7
"18105" = 10
"18107" = 5
"18109" = 3
"18111" = 3
"18113" = 4
"18115" = 2
"18117" = 7
"18119" = 4
"18121" = 6
"18123" = 4
"18125" = 5
"18127" = 3
"18129" = 2
"18131" = 5
"18133" = 4
"18135" = 6
"18137" = 2
"18139" = 4
"18141" = 6
"18143" = 8
"18145" = 4
"18147" = 3
"18149" = 8
"18151" = 4
"18153" = 5
"18155" = 6
"18157" = 9
"18159" = 2
"18161" = 4
"18163" = 7
"18165" = 4
"18167" = 9
"18169" = 3
"18171" = 2
"18173" = 1
"18175" = 6
"18177" = 9
"18179" = 2
"18181" = 3
"18183" = 2
"19001" = 2
"19003" = 4
"19005" = 4
"19007" = 6
"19009" = 2
"19011" = 2
"19013" = 8
"19015" = 2
"19017" = 1
"19019" = 3
"19021" = 4
"19023" = 2
"19025" = 3
"19027" = 2
"19029" = 4
"19031" = 1
"19033" = 4
"19035" = 2
"19037" = 2
"19039" = 4
"19041" = 3
"19043" = 3
"19045" = 4
"19047" = 4
"19049" = 1
"19051" = 7
"19053" = 9
"19055" = 2
"19057" = 5
"19059" = 2
"19061" = 2
"19063" = 4
"19065" = 4
"19067" = 5
"19069" = 3
"19071" = 3
"19073" = 3
"19075" = 1
"19077" = 2
"19079" = 3
"19081" = 2
"19083" = 3
"19085" = 2
"19087" = 5
"19089" = 4
"19091" = 2
"19093" = 4
"19095" = 1
"19097" = 4
"19099" = 4
"19101" = 5
"19103" = 7
"19105" = 3
"19107" = 4
"19109" = 2
"19111" = 6
"19113" = 2
"19115" = 3
"19117" = 7
"19119" = 2
"19121" = 2
"19123" = 6
"19125" = 2
"19127" = 4
"19129" = 2
"19131" = 3
"19133" = 3
"19135" = 4
"19137" = 5
"19139" = 4
"19141" = 3
"19143" = 2
"19145" = 5
"19147" = 3
"19149" = 1
"19151" = 3
"19153" = 3
"19155" = 5
"19157" = 3
"19159" = 8
"19161" = 2
"19163" = 5
"19165" = 2
"19167" = 1
"19169" = 8
"19171" = 3
"19173" = 4
"19175" = 5
"19177" = 6
"19179" = 7
"19181" = 1
"19183" = 2
"19185" = 7
"19187" = 6
"19189" = 2
"19191" = 2
"19193" = 5
"19195" = 3
"19197" = 3
"20001" = 8
"20003" = 5
"20005" = 6
"20007" = 4
"20009" = 4
"20011" = 6
"20013" = 8
"20015" = 2
"20017" = 4
"20019" = 6
"20021" = 9
"20023" = 4
"20025" = 3
"20027" = 3
"20029" = 6
"20031" = 2
"20033" = 2
"20035" = 7
"20037" = 9
"20039" = 4
"20041" = 3
"20043" = 4
"20045" = 6
"20047" = 3
"20049" = 8
"20051" = 4
"20053" = 3
"20055" = 5
"20057" = 4
"20059" = 3
"20061" = 3
"20063" = 3
"20065" = 4
"20067" = 3
"20069" = 1
"20071" = 2
"20073" = 7
"20075" = 4
"20077" = 5
"20079" = 2
"20081" = 3
"20083" = 2
"20085" = 3
"20087" = 2
"20089" = 4
"20091" = 1
"20093" = 3
"20095" = 4
"20097" = 4
"20099" = 7
"20101" = 2
"20103" = 2
"20105" = 4
"20107" = 5
"20109" = 2
"20111" = 9
"20113" = 2
"20115" = 3
"20117" = 3
"20119" = 2
"20121" = 2
"20123" = 2
"20125" = 8
"20127" = 3
"20129" = 3
"20131" = 2
"20133" = 6
"20135" = 2
"20137" = 4
"20139" = 3
"20141" = 5
"20143" = 2
"20145" = 4
"20147" = 3
"20149" = 2
"20151" = 3
"20153" = 4
"20155" = 5
"20157" = 3
"20159" = 4
"20161" = 9
"20163" = 5
"20165" = 4
"20167" = 6
"20169" = 7
"20171" = 2
"20173" = 5
"20175" = 6
"20177" = 7
"20179" = 4
"20181" = 7
"20183" = 4
"20185" = 4
"20187" = 3
"20189" = 3
"20191" = 3
"20193" = 2
"20195" = 3
"20197" = 2
"20199" = 4
"20201" = 2
"20203" = 4
"20205" = 6
"20207" = 7
"20209" = 10
"21001" = 10
"21003" = 10
"21005" = 4
"21007" = 5
"21009" = 9
"21011" = 10
"21013" = 10
"21015" = 2
"21017" = 7
"21019" = 9
"21021" = 6
"21023" = 6
"21025" = 10
"21027" = 9
"21029" = 2
"21031" = 9
"21033" = 8
"21035" = 7
"21037" = 4
"21039" = 5
"21041" = 10
"21043" = 10
"21045" = 10
"21047" = 9
"21049" = 7
"21051" = 10
"21053" = 10
"21055" = 9
"21057" = 10
"21059" = 6
"21061" = 8
"21063" = 10
"21065" = 10
"21067" = 9
"21069" = 8
"21071" = 10
"21073" = 6
"21075" = 10
"21077" = 6
"21079" = 7
"21081" = 8
"21083" = 9
"21085" = 9
"21087" = 9
"21089" = 7
"21091" = 5
"21093" = 5
"21095" = 10
"21097" = 6
"21099" = 10
"21101" = 6
"21103" = 7
"21105" = 8
"21107" = 9
"21109" = 10
"21111" = 7
"21113" = 6
"21115" = 10
"21117" = 4
"21119" = 10
"21121" = 10
"21123" = 9
"21125" = 10
"21127" = 9
"21129" = 10
"21131" = 10
"21133" = 10
"21135" = 10
"21137" = 10
"21139" = 5
"21141" = 8
"21143" = 5
"21145" = 6
"21147" = 10
"21149" = 6
"21151" = 9
"21153" = 10
"21155" = 8
"21157" = 3
"21159" = 10
"21161" = 9
"21163" = 5
"21165" = 10
"21167" = 5
"21169" = 9
"21171" = 10
"21173" = 9
"21175" = 10
"21177" = 9
"21179" = 6
"21181" = 8
"21183" = 9
"21185" = 1
"21187" = 6
"21189" = 10
"21191" = 5
"21193" = 10
"21195" = 10
"21197" = 10
"21199" = 9
"21201" = 10
"21203" = 10
"21205" = 10
"21207" = 10
"21209" = 3
"21211" = 3
"21213" = 6
"21215" = 2
"21217" = 10
"21219" = 10
"21221" = 5
"21223" = 5
"21225" = 9
"21227" = 9
"21229" = 6
"21231" = 10
"21233" = 5
"21235" = 10
"21237" = 10
"21239" = 3
"22001" = 9
"22003" = 9
"22005" = 4
"22007" = 6
"22009" = 9
"22011" = 6
"22013" = 10
"22015" = 4
"22017" = 9
"22019" = 7
"22021" = 9
"22023" = 4
"22025" = 10
"22027" = 10
"22029" = 10
"22031" = 9
"22033" = 7
"22035" = 10
"22037" = 8
"22039" = 10
"22041" = 10
"22043" = 9
"22045" = 10
"22047" = 10
"22049" = 9
"22051" = 6
"22053" = 9
"22055" = 8
"22057" = 4
"22059" = 5
"22061" = 10
"22063" = 4
"22065" = 10
"22067" = 10
"22069" = 10
"22071" = 10
"22073" = 9
"22075" = 5
"22077" = 7
"22079" = 9
"22081" = 10
"22083" = 10
"22085" = 10
"22087" = 8
"22089" = 4
"22091" = 10
"22093" = 6
"22095" = 8
"22097" = 10
"22099" = 10
"22101" = 9
"22103" = 2
"22105" = 9
"22107" = 10
"22109" = 8
"22111" = 9
"22113" = 7
"22115" = 4
"22117" = 10
"22119" = 10
"22121" = 5
"22123" = 10
"22125" = 9
"22127" = 10
"23001" = 5
"23003" = 4
"23005" = 2
"23007" = 6
"23009" = 4
"23011" = 3
"23013" = 4
"23015" = 4
"23017" = 5
"23019" = 6
"23021" = 6
"23023" = 2
"23025" = 8
"23027" = 6
"23029" = 9
"23031" = 2
"24001" = 7
"24003" = 1
"24005" = 1
"24009" = 1
"24011" = 4
"24013" = 1
"24015" = 2
"24017" = 1
"24019" = 6
"24021" = 1
"24023" = 5
"24025" = 1
"24027" = 1
"24029" = 5
"24031" = 1
"24033" = 2
"24035" = 1
"24037" = 1
"24039" = 9
"24041" = 2
"24043" = 3
"24045" = 6
"24047" = 2
"24510" = 10
"25001" = 3
"25003" = 4
"25005" = 4
"25007" = 2
"25009" = 2
"25011" = 3
"25013" = 7
"25015" = 4
"25017" = 1
"25019" = 1
"25021" = 1
"25023" = 2
"25025" = 10
"25027" = 3
"26001" = 6
"26003" = 5
"26005" = 5
"26007" = 7
"26009" = 5
"26011" = 8
"26013" = 4
"26015" = 3
"26017" = 6
"26019" = 4
"26021" = 7
"26023" = 9
"26025" = 7
"26027" = 6
"26029" = 4
"26031" = 7
"26033" = 9
"26035" = 10
"26037" = 2
"26039" = 6
"26041" = 5
"26043" = 4
"26045" = 3
"26047" = 3
"26049" = 9
"26051" = 9
"26053" = 9
"26055" = 3
"26057" = 8
"26059" = 7
"26061" = 9
"26063" = 6
"26065" = 9
"26067" = 6
"26069" = 9
"26071" = 5
"26073" = 10
"26075" = 9
"26077" = 9
"26079" = 8
"26081" = 6
"26083" = 4
"26085" = 10
"26087" = 4
"26089" = 2
"26091" = 5
"26093" = 1
"26095" = 9
"26097" = 5
"26099" = 4
"26101" = 7
"26103" = 5
"26105" = 6
"26107" = 10
"26109" = 4
"26111" = 3
"26113" = 6
"26115" = 3
"26117" = 9
"26119" = 9
"26121" = 9
"26123" = 9
"26125" = 2
"26127" = 10
"26129" = 9
"26131" = 6
"26133" = 9
"26135" = 9
"26137" = 4
"26139" = 3
"26141" = 5
"26143" = 10
"26145" = 8
"26147" = 6
"26149" = 6
"26151" = 7
"26153" = 6
"26155" = 5
"26157" = 6
"26159" = 6
"26161" = 4
"26163" = 10
"26165" = 7
"27001" = 4
"27003" = 1
"27005" = 5
"27007" = 9
"27009" = 2
"27011" = 3
"27013" = 7
"27015" = 2
"27017" = 3
"27019" = 1
"27021" = 6
"27023" = 2
"27025" = 1
"27027" = 4
"27029" = 6
"27031" = 2
"27033" = 3
"27035" = 3
"27037" = 1
"27039" = 1
"27041" = 2
"27043" = 3
"27045" = 4
"27047" = 3
"27049" = 2
"27051" = 3
"27053" = 4
"27055" = 2
"27057" = 4
"27059" = 2
"27061" = 3
"27063" = 2
"27065" = 4
"27067" = 5
"27069" = 2
"27071" = 5
"27073" = 2
"27075" = 3
"27077" = 3
"27079" = 2
"27081" = 2
"27083" = 3
"27085" = 2
"27087" = 10
"27089" = 1
"27091" = 3
"27093" = 2
"27095" = 4
"27097" = 4
"27099" = 3
"27101" = 2
"27103" = 2
"27105" = 4
"27107" = 3
"27109" = 2
"27111" = 4
"27113" = 3
"27115" = 5
"27117" = 2
"27119" = 3
"27121" = 2
"27123" = 7
"27125" = 3
"27127" = 2
"27129" = 3
"27131" = 2
"27133" = 3
"27135" = 2
"27137" = 7
"27139" = 1
"27141" = 1
"27143" = 2
"27145" = 3
"27147" = 2
"27149" = 3
"27151" = 2
"27153" = 7
"27155" = 4
"27157" = 1
"27159" = 7
"27161" = 2
"27163" = 1
"27165" = 3
"27167" = 2
"27169" = 6
"27171" = 1
"27173" = 4
"28001" = 10
"28003" = 10
"28005" = 10
"28007" = 10
"28009" = 10
"28011" = 10
"28013" = 10
"28015" = 8
"28017" = 10
"28019" = 10
"28021" = 10
"28023" = 10
"28025" = 10
"28027" = 10
"28029" = 10
"28031" = 9
"28033" = 2
"28035" = 10
"28037" = 9
"28039" = 7
"28041" = 10
"28043" = 9
"28045" = 8
"28047" = 9
"28049" = 10
"28051" = 10
"28053" = 10
"28055" = 10
"28057" = 7
"28059" = 6
"28061" = 9
"28063" = 10
"28065" = 10
"28067" = 10
"28069" = 10
"28071" = 9
"28073" = 6
"28075" = 10
"28077" = 8
"28079" = 10
"28081" = 9
"28083" = 10
"28085" = 8
"28087" = 10
"28089" = 4
"28091" = 10
"28093" = 10
"28095" = 10
"28097" = 10
"28099" = 10
"28101" = 9
"28103" = 10
"28105" = 10
"28107" = 10
"28109" = 9
"28111" = 9
"28113" = 10
"28115" = 6
"28117" = 10
"28119" = 10
"28121" = 4
"28123" = 9
"28125" = 10
"28127" = 10
"28129" = 9
"28131" = 9
"28133" = 10
"28135" = 10
"28137" = 8
"28139" = 9
"28141" = 8
"28143" = 10
"28145" = 9
"28147" = 10
"28149" = 10
"28151" = 10
"28153" = 10
"28155" = 10
"28157" = 10
"28159" = 10
"28161" = 10
"28163" = 10
"29001" = 10
"29003" = 2
"29005" = 3
"29007" = 8
"29009" = 8
"29011" = 7
"29013" = 6
"29015" = 9
"29017" = 9
"29019" = 8
"29021" = 6
"29023" = 9
"29025" = 4
"29027" = 4
"29029" = 5
"29031" = 5
"29033" = 6
"29035" = 10
"29037" = 2
"29039" = 9
"29041" = 4
"29043" = 3
"29045" = 6
"29047" = 2
"29049" = 3
"29051" = 3
"29053" = 6
"29055" = 9
"29057" = 9
"29059" = 9
"29061" = 7
"29063" = 6
"29065" = 9
"29067" = 10
"29069" = 10
"29071" = 4
"29073" = 4
"29075" = 5
"29077" = 9
"29079" = 7
"29081" = 7
"29083" = 7
"29085" = 10
"29087" = 5
"29089" = 6
"29091" = 9
"29093" = 9
"29095" = 7
"29097" = 7
"29099" = 3
"29101" = 8
"29103" = 9
"29105" = 8
"29107" = 3
"29109" = 6
"29111" = 6
"29113" = 3
"29115" = 6
"29117" = 6
"29119" = 9
"29121" = 5
"29123" = 9
"29125" = 5
"29127" = 6
"29129" = 5
"29131" = 9
"29133" = 10
"29135" = 5
"29137" = 5
"29139" = 7
"29141" = 9
"29143" = 10
"29145" = 6
"29147" = 7
"29149" = 10
"29151" = 3
"29153" = 10
"29155" = 10
"29157" = 4
"29159" = 8
"29161" = 8
"29163" = 8
"29165" = 1
"29167" = 9
"29169" = 5
"29171" = 9
"29173" = 3
"29175" = 8
"29177" = 3
"29179" = 10
"29181" = 10
"29183" = 1
"29185" = 9
"29186" = 3
"29187" = 8
"29189" = 2
"29195" = 9
"29197" = 9
"29199" = 6
"29201" = 8
"29203" = 10
"29205" = 5
"29207" = 8
"29209" = 6
"29211" = 7
"29213" = 9
"29215" = 10
"29217" = 8
"29219" = 4
"29221" = 10
"29223" = 10
"29225" = 7
"29227" = 6
"29229" = 10
"29510" = 10
"30001" = 8
"30003" = 10
"30005" = 10
"30007" = 3
"30009" = 4
"30011" = 8
"30013" = 4
"30015" = 6
"30017" = 5
"30019" = 3
"30021" = 4
"30023" = 8
"30025" = 2
"30027" = 4
"30029" = 5
"30031" = 4
"30033" = 9
"30035" = 10
"30037" = 9
"30039" = 5
"30041" = 8
"30043" = 2
"30045" = 6
"30047" = 9
"30049" = 3
"30051" = 10
"30053" = 8
"30055" = 6
"30057" = 3
"30059" = 9
"30061" = 8
"30063" = 5
"30065" = 8
"30067" = 4
"30069" = 9
"30071" = 6
"30073" = 9
"30075" = 5
"30077" = 9
"30079" = 6
"30081" = 7
"30083" = 3
"30085" = 10
"30087" = 8
"30089" = 9
"30091" = 3
"30093" = 8
"30095" = 2
"30097" = 3
"30099" = 6
"30101" = 6
"30103" = 3
"30105" = 4
"30107" = 7
"30109" = 4
"30111" = 4
"31001" = 4
"31003" = 4
"31005" = 3
"31007" = 4
"31009" = 9
"31011" = 2
"31013" = 4
"31015" = 4
"31017" = 4
"31019" = 4
"31021" = 3
"31023" = 2
"31025" = 1
"31027" = 3
"31029" = 3
"31031" = 4
"31033" = 2
"31035" = 3
"31037" = 3
"31039" = 2
"31041" = 4
"31043" = 4
"31045" = 7
"31047" = 3
"31049" = 4
"31051" = 2
"31053" = 4
"31055" = 5
"31057" = 4
"31059" = 2
"31061" = 5
"31063" = 4
"31065" = 4
"31067" = 4
"31069" = 6
"31071" = 5
"31073" = 2
"31075" = 3
"31077" = 4
"31079" = 4
"31081" = 2
"31083" = 3
"31085" = 7
"31087" = 5
"31089" = 4
"31091" = 2
"31093" = 2
"31095" = 4
"31097" = 3
"31099" = 2
"31101" = 3
"31103" = 10
"31105" = 4
"31107" = 5
"31109" = 5
"31111" = 3
"31113" = 4
"31115" = 7
"31117" = 8
"31119" = 4
"31121" = 3
"31123" = 6
"31125" = 4
"31127" = 4
"31129" = 4
"31131" = 2
"31133" = 4
"31135" = 2
"31137" = 2
"31139" = 2
"31141" = 2
"31143" = 2
"31145" = 4
"31147" = 4
"31149" = 6
"31151" = 2
"31153" = 1
"31155" = 2
"31157" = 6
"31159" = 1
"31161" = 7
"31163" = 4
"31165" = 7
"31167" = 2
"31169" = 3
"31171" = 6
"31173" = 10
"31175" = 5
"31177" = 1
"31179" = 5
"31181" = 3
"31183" = 9
"31185" = 2
"32001" = 3
"32003" = 5
"32005" = 2
"32007" = 2
"32009" = 5
"32011" = 2
"32013" = 2
"32015" = 2
"32017" = 4
"32019" = 3
"32021" = 6
"32023" = 8
"32027" = 8
"32029" = 2
"32031" = 5
"32033" = 4
"32510" = 5
"33001" = 2
"33003" = 2
"33005" = 3
"33007" = 5
"33009" = 3
"33011" = 1
"33013" = 2
"33015" = 1
"33017" = 3
"33019" = 3
"34001" = 4
"34003" = 1
"34005" = 1
"34007" = 3
"34009" = 3
"34011" = 7
"34013" = 6
"34015" = 1
"34017" = 6
"34019" = 1
"34021" = 3
"34023" = 1
"34025" = 1
"34027" = 1
"34029" = 3
"34031" = 6
"34033" = 3
"34035" = 1
"34037" = 1
"34039" = 3
"34041" = 1
"35001" = 6
"35003" = 10
"35005" = 10
"35006" = 10
"35007" = 8
"35009" = 9
"35011" = 8
"35013" = 10
"35015" = 6
"35017" = 8
"35019" = 10
"35021" = 4
"35023" = 10
"35025" = 8
"35027" = 8
"35028" = 1
"35029" = 10
"35031" = 10
"35033" = 10
"35035" = 10
"35037" = 10
"35039" = 9
"35041" = 10
"35043" = 4
"35045" = 10
"35047" = 10
"35049" = 6
"35051" = 9
"35053" = 10
"35055" = 8
"35057" = 10
"35059" = 8
"35061" = 10
"36001" = 4
"36003" = 7
"36005" = 10
"36007" = 6
"36009" = 5
"36011" = 4
"36013" = 7
"36015" = 6
"36017" = 6
"36019" = 6
"36021" = 2
"36023" = 5
"36025" = 3
"36027" = 1
"36029" = 5
"36031" = 4
"36033" = 6
"36035" = 6
"36037" = 3
"36039" = 7
"36041" = 2
"36043" = 6
"36045" = 5
"36047" = 10
"36049" = 5
"36051" = 4
"36053" = 3
"36055" = 5
"36057" = 7
"36059" = 1
"36061" = 6
"36063" = 4
"36065" = 5
"36067" = 4
"36069" = 2
"36071" = 3
"36073" = 4
"36075" = 7
"36077" = 6
"36079" = 1
"36081" = 5
"36083" = 4
"36085" = 3
"36087" = 3
"36089" = 7
"36091" = 1
"36093" = 3
"36095" = 4
"36097" = 4
"36099" = 4
"36101" = 5
"36103" = 1
"36105" = 9
"36107" = 2
"36109" = 9
"36111" = 4
"36113" = 2
"36115" = 3
"36117" = 2
"36119" = 2
"36121" = 3
"36123" = 7
"37001" = 8
"37003" = 7
"37005" = 10
"37007" = 10
"37009" = 9
"37011" = 10
"37013" = 9
"37015" = 10
"37017" = 10
"37019" = 6
"37021" = 7
"37023" = 8
"37025" = 4
"37027" = 8
"37029" = 2
"37031" = 4
"37033" = 9
"37035" = 5
"37037" = 5
"37039" = 8
"37041" = 9
"37043" = 8
"37045" = 9
"37047" = 10
"37049" = 7
"37051" = 8
"37053" = 3
"37055" = 3
"37057" = 7
"37059" = 4
"37061" = 10
"37063" = 8
"37065" = 10
"37067" = 6
"37069" = 6
"37071" = 9
"37073" = 7
"37075" = 10
"37077" = 6
"37079" = 10
"37081" = 8
"37083" = 10
"37085" = 6
"37087" = 5
"37089" = 6
"37091" = 10
"37093" = 8
"37095" = 10
"37097" = 4
"37099" = 9
"37101" = 6
"37103" = 8
"37105" = 8
"37107" = 10
"37109" = 5
"37111" = 9
"37113" = 9
"37115" = 9
"37117" = 10
"37119" = 6
"37121" = 8
"37123" = 10
"37125" = 6
"37127" = 6
"37129" = 8
"37131" = 10
"37133" = 6
"37135" = 7
"37137" = 5
"37139" = 10
"37141" = 6
"37143" = 6
"37145" = 6
"37147" = 9
"37149" = 5
"37151" = 8
"37153" = 10
"37155" = 10
"37157" = 8
"37159" = 9
"37161" = 10
"37163" = 9
"37165" = 10
"37167" = 6
"37169" = 5
"37171" = 9
"37173" = 8
"37175" = 6
"37177" = 10
"37179" = 2
"37181" = 10
"37183" = 3
"37185" = 10
"37187" = 10
"37189" = 10
"37191" = 9
"37193" = 9
"37195" = 10
"37197" = 5
"37199" = 9
"38001" = 2
"38003" = 3
"38005" = 10
"38007" = 3
"38009" = 3
"38011" = 1
"38013" = 2
"38015" = 2
"38017" = 3
"38019" = 2
"38021" = 3
"38023" = 2
"38025" = 3
"38027" = 3
"38029" = 6
"38031" = 2
"38033" = 4
"38035" = 6
"38037" = 8
"38039" = 2
"38041" = 3
"38043" = 6
"38045" = 2
"38047" = 5
"38049" = 4
"38051" = 5
"38053" = 4
"38055" = 2
"38057" = 1
"38059" = 2
"38061" = 4
"38063" = 2
"38065" = 3
"38067" = 2
"38069" = 4
"38071" = 4
"38073" = 2
"38075" = 2
"38077" = 3
"38079" = 10
"38081" = 2
"38083" = 7
"38085" = 10
"38087" = 4
"38089" = 2
"38091" = 1
"38093" = 3
"38095" = 2
"38097" = 2
"38099" = 3
"38101" = 4
"38103" = 4
"38105" = 2
"39001" = 10
"39003" = 8
"39005" = 6
"39007" = 6
"39009" = 10
"39011" = 2
"39013" = 6
"39015" = 4
"39017" = 4
"39019" = 6
"39021" = 4
"39023" = 9
"39025" = 2
"39027" = 6
"39029" = 8
"39031" = 9
"39033" = 6
"39035" = 8
"39037" = 3
"39039" = 3
"39041" = 1
"39043" = 5
"39045" = 3
"39047" = 6
"39049" = 8
"39051" = 3
"39053" = 8
"39055" = 1
"39057" = 4
"39059" = 9
"39061" = 8
"39063" = 3
"39065" = 7
"39067" = 8
"39069" = 4
"39071" = 8
"39073" = 6
"39075" = 6
"39077" = 4
"39079" = 10
"39081" = 8
"39083" = 6
"39085" = 2
"39087" = 9
"39089" = 4
"39091" = 7
"39093" = 5
"39095" = 9
"39097" = 5
"39099" = 7
"39101" = 9
"39103" = 1
"39105" = 10
"39107" = 2
"39109" = 3
"39111" = 7
"39113" = 8
"39115" = 9
"39117" = 4
"39119" = 8
"39121" = 7
"39123" = 2
"39125" = 4
"39127" = 9
"39129" = 4
"39131" = 10
"39133" = 5
"39135" = 3
"39137" = 2
"39139" = 5
"39141" = 9
"39143" = 3
"39145" = 10
"39147" = 5
"39149" = 3
"39151" = 5
"39153" = 6
"39155" = 8
"39157" = 5
"39159" = 1
"39161" = 4
"39163" = 10
"39165" = 1
"39167" = 6
"39169" = 4
"39171" = 3
"39173" = 4
"39175" = 2
"40001" = 10
"40003" = 7
"40005" = 10
"40007" = 3
"40009" = 8
"40011" = 9
"40013" = 7
"40015" = 9
"40017" = 2
"40019" = 8
"40021" = 10
"40023" = 10
"40025" = 8
"40027" = 4
"40029" = 9
"40031" = 7
"40033" = 6
"40035" = 6
"40037" = 6
"40039" = 7
"40041" = 10
"40043" = 4
"40045" = 4
"40047" = 6
"40049" = 6
"40051" = 6
"40053" = 4
"40055" = 10
"40057" = 10
"40059" = 3
"40061" = 7
"40063" = 10
"40065" = 7
"40067" = 9
"40069" = 10
"40071" = 7
"40073" = 3
"40075" = 10
"40077" = 8
"40079" = 10
"40081" = 5
"40083" = 5
"40085" = 6
"40087" = 3
"40089" = 10
"40091" = 9
"40093" = 4
"40095" = 8
"40097" = 8
"40099" = 5
"40101" = 9
"40103" = 5
"40105" = 6
"40107" = 10
"40109" = 7
"40111" = 9
"40113" = 6
"40115" = 9
"40117" = 6
"40119" = 9
"40121" = 8
"40123" = 8
"40125" = 8
"40127" = 10
"40129" = 4
"40131" = 2
"40133" = 10
"40135" = 9
"40137" = 6
"40139" = 3
"40141" = 10
"40143" = 6
"40145" = 3
"40147" = 4
"40149" = 5
"40151" = 6
"40153" = 5
"41001" = 9
"41003" = 9
"41005" = 2
"41007" = 5
"41009" = 4
"41011" = 9
"41013" = 7
"41015" = 6
"41017" = 5
"41019" = 9
"41021" = 3
"41023" = 6
"41025" = 9
"41027" = 4
"41029" = 6
"41031" = 9
"41033" = 8
"41035" = 7
"41037" = 9
"41039" = 9
"41041" = 7
"41043" = 8
"41045" = 10
"41047" = 8
"41049" = 6
"41051" = 8
"41053" = 6
"41055" = 4
"41057" = 6
"41059" = 6
"41061" = 6
"41063" = 6
"41065" = 6
"41067" = 2
"41069" = 9
"41071" = 5
"42001" = 2
"42003" = 3
"42005" = 4
"42007" = 5
"42009" = 4
"42011" = 4
"42013" = 4
"42015" = 3
"42017" = 1
"42019" = 2
"42021" = 4
"42023" = 5
"42025" = 3
"42027" = 8
"42029" = 1
"42031" = 8
"42033" = 7
"42035" = 7
"42037" = 6
"42039" = 9
"42041" = 1
"42043" = 4
"42045" = 2
"42047" = 3
"42049" = 7
"42051" = 9
"42053" = 9
"42055" = 2
"42057" = 2
"42059" = 8
"42061" = 5
"42063" = 8
"42065" = 6
"42067" = 3
"42069" = 4
"42071" = 2
"42073" = 6
"42075" = 3
"42077" = 4
"42079" = 6
"42081" = 7
"42083" = 5
"42085" = 6
"42087" = 6
"42089" = 4
"42091" = 1
"42093" = 3
"42095" = 2
"42097" = 5
"42099" = 2
"42101" = 10
"42103" = 2
"42105" = 5
"42107" = 4
"42109" = 4
"42111" = 5
"42113" = 5
"42115" = 4
"42117" = 6
"42119" = 4
"42121" = 6
"42123" = 4
"42125" = 2
"42127" = 4
"42129" = 2
"42131" = 4
"42133" = 2
"44001" = 1
"44003" = 2
"44005" = 2
"44007" = 7
"44009" = 2
"45001" = 9
"45003" = 8
"45005" = 10
"45007" = 8
"45009" = 10
"45011" = 10
"45013" = 4
"45015" = 5
"45017" = 8
"45019" = 8
"45021" = 9
"45023" = 9
"45025" = 10
"45027" = 10
"45029" = 10
"45031" = 10
"45033" = 10
"45035" = 3
"45037" = 9
"45039" = 10
"45041" = 9
"45043" = 9
"45045" = 6
"45047" = 10
"45049" = 10
"45051" = 9
"45053" = 10
"45055" = 8
"45057" = 9
"45059" = 9
"45061" = 10
"45063" = 4
"45065" = 9
"45067" = 10
"45069" = 10
"45071" = 8
"45073" = 4
"45075" = 10
"45077" = 7
"45079" = 7
"45081" = 9
"45083" = 7
"45085" = 9
"45087" = 8
"45089" = 10
"45091" = 4
"46003" = 3
"46005" = 5
"46007" = 10
"46009" = 7
"46011" = 7
"46013" = 2
"46015" = 5
"46017" = 10
"46019" = 5
"46021" = 3
"46023" = 10
"46025" = 5
"46027" = 9
"46029" = 3
"46031" = 10
"46033" = 3
"46035" = 5
"46037" = 7
"46039" = 2
"46041" = 10
"46043" = 5
"46045" = 3
"46047" = 6
"46049" = 5
"46051" = 3
"46053" = 10
"46055" = 4
"46057" = 3
"46059" = 3
"46061" = 2
"46063" = 7
"46065" = 2
"46067" = 3
"46069" = 4
"46071" = 10
"46073" = 6
"46075" = 6
"46077" = 2
"46079" = 3
"46081" = 4
"46083" = 1
"46085" = 10
"46087" = 2
"46089" = 8
"46091" = 5
"46093" = 2
"46095" = 10
"46097" = 4
"46099" = 3
"46101" = 3
"46103" = 5
"46105" = 7
"46107" = 3
"46109" = 9
"46111" = 5
"46113" = 10
"46115" = 4
"46117" = 2
"46119" = 2
"46121" = 10
"46123" = 9
"46125" = 3
"46127" = 1
"46129" = 6
"46135" = 3
"46137" = 10
"47001" = 6
"47003" = 10
"47005" = 9
"47007" = 10
"47009" = 4
"47011" = 9
"47013" = 10
"47015" = 6
"47017" = 9
"47019" = 10
"47021" = 3
"47023" = 9
"47025" = 10
"47027" = 10
"47029" = 10
"47031" = 10
"47033" = 9
"47035" = 8
"47037" = 9
"47039" = 9
"47041" = 9
"47043" = 4
"47045" = 9
"47047" = 4
"47049" = 10
"47051" = 5
"47053" = 8
"47055" = 7
"47057" = 9
"47059" = 10
"47061" = 10
"47063" = 9
"47065" = 6
"47067" = 10
"47069" = 10
"47071" = 10
"47073" = 8
"47075" = 10
"47077" = 7
"47079" = 9
"47081" = 9
"47083" = 9
"47085" = 6
"47087" = 9
"47089" = 6
"47091" = 10
"47093" = 4
"47095" = 10
"47097" = 10
"47099" = 8
"47101" = 9
"47103" = 7
"47105" = 5
"47107" = 8
"47109" = 10
"47111" = 10
"47113" = 9
"47115" = 10
"47117" = 5
"47119" = 5
"47121" = 10
"47123" = 9
"47125" = 6
"47127" = 4
"47129" = 9
"47131" = 6
"47133" = 9
"47135" = 9
"47137" = 9
"47139" = 9
"47141" = 9
"47143" = 9
"47145" = 5
"47147" = 4
"47149" = 5
"47151" = 10
"47153" = 10
"47155" = 6
"47157" = 9
"47159" = 9
"47161" = 5
"47163" = 8
"47165" = 4
"47167" = 4
"47169" = 7
"47171" = 7
"47173" = 10
"47175" = 10
"47177" = 10
"47179" = 8
"47181" = 10
"47183" = 9
"47185" = 9
"47187" = 1
"47189" = 2
"48001" = 9
"48003" = 4
"48005" = 8
"48007" = 10
"48009" = 3
"48011" = 2
"48013" = 9
"48015" = 4
"48017" = 8
"48019" = 6
"48021" = 6
"48023" = 9
"48025" = 10
"48027" = 4
"48029" = 7
"48031" = 4
"48033" = 3
"48035" = 7
"48037" = 8
"48039" = 3
"48041" = 10
"48043" = 5
"48045" = 6
"48047" = 10
"48049" = 8
"48051" = 5
"48053" = 5
"48055" = 7
"48057" = 9
"48059" = 6
"48061" = 10
"48063" = 9
"48065" = 2
"48067" = 9
"48069" = 9
"48071" = 2
"48073" = 10
"48075" = 10
"48077" = 4
"48079" = 9
"48081" = 4
"48083" = 9
"48085" = 1
"48087" = 8
"48089" = 7
"48091" = 3
"48093" = 9
"48095" = 10
"48097" = 5
"48099" = 4
"48101" = 9
"48103" = 2
"48105" = 6
"48107" = 10
"48109" = 10
"48111" = 5
"48113" = 8
"48115" = 10
"48117" = 9
"48119" = 8
"48121" = 1
"48123" = 9
"48125" = 9
"48127" = 10
"48129" = 7
"48131" = 10
"48133" = 10
"48135" = 9
"48137" = 10
"48139" = 3
"48141" = 10
"48143" = 8
"48145" = 10
"48147" = 6
"48149" = 4
"48151" = 5
"48153" = 9
"48155" = 8
"48157" = 2
"48159" = 6
"48161" = 8
"48163" = 10
"48165" = 8
"48167" = 4
"48169" = 10
"48171" = 3
"48173" = 3
"48175" = 6
"48177" = 9
"48179" = 6
"48181" = 5
"48183" = 9
"48185" = 9
"48187" = 3
"48189" = 9
"48191" = 10
"48193" = 6
"48195" = 5
"48197" = 10
"48199" = 4
"48201" = 8
"48203" = 7
"48205" = 3
"48207" = 10
"48209" = 5
"48211" = 2
"48213" = 9
"48215" = 10
"48217" = 7
"48219" = 9
"48221" = 3
"48223" = 8
"48225" = 10
"48227" = 10
"48229" = 10
"48231" = 9
"48233" = 4
"48235" = 2
"48237" = 6
"48239" = 6
"48241" = 9
"48243" = 3
"48245" = 10
"48247" = 10
"48249" = 9
"48251" = 4
"48253" = 10
"48255" = 10
"48257" = 3
"48259" = 2
"48261" = 4
"48263" = 3
"48265" = 6
"48267" = 8
"48269" = 4
"48271" = 10
"48273" = 10
"48275" = 10
"48277" = 8
"48279" = 9
"48281" = 5
"48283" = 10
"48285" = 5
"48287" = 4
"48289" = 5
"48291" = 8
"48293" = 8
"48295" = 4
"48297" = 8
"48299" = 6
"48301" = 5
"48303" = 9
"48305" = 9
"48307" = 10
"48309" = 9
"48311" = 3
"48313" = 10
"48315" = 10
"48317" = 6
"48319" = 6
"48321" = 9
"48323" = 10
"48325" = 7
"48327" = 10
"48329" = 5
"48331" = 9
"48333" = 7
"48335" = 10
"48337" = 6
"48339" = 3
"48341" = 5
"48343" = 9
"48345" = 6
"48347" = 10
"48349" = 9
"48351" = 10
"48353" = 9
"48355" = 9
"48357" = 4
"48359" = 4
"48361" = 5
"48363" = 7
"48365" = 4
"48367" = 3
"48369" = 5
"48371" = 10
"48373" = 9
"48375" = 10
"48377" = 10
"48379" = 6
"48381" = 2
"48383" = 3
"48385" = 10
"48387" = 9
"48389" = 10
"48391" = 8
"48393" = 1
"48395" = 9
"48397" = 1
"48399" = 10
"48401" = 5
"48403" = 8
"48405" = 9
"48407" = 9
"48409" = 9
"48411" = 9
"48413" = 7
"48415" = 7
"48417" = 4
"48419" = 10
"48421" = 4
"48423" = 5
"48425" = 2
"48427" = 10
"48429" = 9
"48431" = 4
"48433" = 7
"48435" = 4
"48437" = 9
"48439" = 5
"48441" = 8
"48443" = 5
"48445" = 10
"48447" = 5
"48449" = 9
"48451" = 9
"48453" = 8
"48455" = 8
"48457" = 9
"48459" = 6
"48461" = 6
"48463" = 10
"48465" = 10
"48467" = 7
"48469" = 8
"48471" = 10
"48473" = 9
"48475" = 9
"48477" = 5
"48479" = 10
"48481" = 9
"48483" = 4
"48485" = 7
"48487" = 7
"48489" = 10
"48491" = 1
"48493" = 3
"48495" = 6
"48497" = 4
"48499" = 8
"48501" = 5
"48503" = 7
"48505" = 10
"48507" = 10
"49001" = 4
"49003" = 2
"49005" = 6
"49007" = 5
"49009" = 1
"49011" = 1
"49013" = 4
"49015" = 3
"49017" = 3
"49019" = 5
"49021" = 9
"49023" = 3
"49025" = 4
"49027" = 4
"49029" = 1
"49031" = 9
"49033" = 3
"49035" = 4
"49037" = 10
"49039" = 8
"49041" = 5
"49043" = 1
"49045" = 2
"49047" = 5
"49049" = 5
"49051" = 1
"49053" = 5
"49055" = 5
"49057" = 4
"50001" = 3
"50003" = 4
"50005" = 6
"50007" = 3
"50009" = 7
"50011" = 3
"50013" = 1
"50015" = 4
"50017" = 4
"50019" = 7
"50021" = 4
"50023" = 3
"50025" = 4
"50027" = 2
"51001" = 9
"51003" = 2
"51005" = 4
"51007" = 3
"51009" = 4
"51011" = 4
"51013" = 1
"51015" = 2
"51017" = 3
"51019" = 2
"51021" = 5
"51023" = 1
"51025" = 9
"51027" = 10
"51029" = 9
"51031" = 5
"51033" = 3
"51035" = 7
"51036" = 3
"51037" = 8
"51041" = 1
"51043" = 2
"51045" = 3
"51047" = 2
"51049" = 7
"51051" = 10
"51053" = 3
"51057" = 4
"51059" = 1
"51061" = 1
"51063" = 4
"51065" = 1
"51067" = 5
"51069" = 1
"51071" = 4
"51073" = 2
"51075" = 1
"51077" = 7
"51079" = 2
"51081" = 10
"51083" = 9
"51085" = 1
"51087" = 2
"51089" = 8
"51091" = 5
"51093" = 2
"51095" = 1
"51097" = 4
"51099" = 1
"51101" = 1
"51103" = 4
"51105" = 10
"51107" = 1
"51109" = 2
"51111" = 9
"51113" = 3
"51115" = 2
"51117" = 9
"51119" = 4
"51121" = 9
"51125" = 4
"51127" = 1
"51131" = 8
"51133" = 5
"51135" = 9
"51137" = 2
"51139" = 6
"51141" = 8
"51143" = 6
"51145" = 1
"51147" = 10
"51149" = 2
"51153" = 1
"51155" = 6
"51157" = 2
"51159" = 8
"51161" = 1
"51163" = 3
"51165" = 3
"51167" = 8
"51169" = 8
"51171" = 3
"51173" = 8
"51175" = 6
"51177" = 1
"51179" = 1
"51181" = 3
"51183" = 10
"51185" = 8
"51187" = 2
"51191" = 4
"51193" = 5
"51195" = 10
"51197" = 6
"51199" = 1
"51510" = 2
"51515" = 7
"51520" = 9
"51530" = 6
"51540" = 9
"51550" = 1
"51570" = 2
"51580" = 6
"51590" = 10
"51595" = 10
"51600" = 1
"51610" = 1
"51620" = 9
"51630" = 9
"51640" = 10
"51650" = 4
"51660" = 10
"51670" = 7
"51678" = 9
"51680" = 10
"51683" = 3
"51685" = 2
"51690" = 10
"51700" = 5
"51710" = 8
"51720" = 9
"51730" = 10
"51735" = 1
"51740" = 8
"51750" = 10
"51760" = 10
"51770" = 10
"51775" = 2
"51790" = 5
"51800" = 3
"51810" = 1
"51820" = 7
"51830" = 8
"51840" = 9
"53001" = 9
"53003" = 6
"53005" = 4
"53007" = 5
"53009" = 6
"53011" = 4
"53013" = 5
"53015" = 9
"53017" = 5
"53019" = 9
"53021" = 8
"53023" = 4
"53025" = 9
"53027" = 8
"53029" = 2
"53031" = 3
"53033" = 3
"53035" = 3
"53037" = 9
"53039" = 7
"53041" = 6
"53043" = 3
"53045" = 6
"53047" = 10
"53049" = 8
"53051" = 8
"53053" = 3
"53055" = 3
"53057" = 4
"53059" = 4
"53061" = 2
"53063" = 5
"53065" = 7
"53067" = 2
"53069" = 4
"53071" = 6
"53073" = 5
"53075" = 10
"53077" = 10
"54001" = 7
"54003" = 4
"54005" = 8
"54007" = 10
"54009" = 5
"54011" = 10
"54013" = 10
"54015" = 10
"54017" = 9
"54019" = 10
"54021" = 10
"54023" = 7
"54025" = 9
"54027" = 8
"54029" = 4
"54031" = 6
"54033" = 7
"54035" = 9
"54037" = 3
"54039" = 5
"54041" = 9
"54043" = 10
"54045" = 10
"54047" = 10
"54049" = 7
"54051" = 7
"54053" = 8
"54055" = 9
"54057" = 6
"54059" = 10
"54061" = 10
"54063" = 8
"54065" = 4
"54067" = 8
"54069" = 6
"54071" = 5
"54073" = 5
"54075" = 9
"54077" = 6
"54079" = 2
"54081" = 8
"54083" = 8
"54085" = 9
"54087" = 10
"54089" = 10
"54091" = 9
"54093" = 9
"54095" = 6
"54097" = 10
"54099" = 9
"54101" = 10
"54103" = 8
"54105" = 10
"54107" = 6
"54109" = 9
"55001" = 5
"55003" = 8
"55005" = 4
"55007" = 5
"55009" = 2
"55011" = 3
"55013" = 5
"55015" = 1
"55017" = 3
"55019" = 5
"55021" = 2
"55023" = 5
"55025" = 3
"55027" = 2
"55029" = 3
"55031" = 5
"55033" = 5
"55035" = 6
"55037" = 4
"55039" = 3
"55041" = 7
"55043" = 6
"55045" = 2
"55047" = 4
"55049" = 2
"55051" = 7
"55053" = 8
"55055" = 3
"55057" = 6
"55059" = 4
"55061" = 2
"55063" = 4
"55065" = 3
"55067" = 4
"55069" = 3
"55071" = 3
"55073" = 3
"55075" = 5
"55077" = 3
"55078" = 10
"55079" = 10
"55081" = 6
"55083" = 4
"55085" = 3
"55087" = 2
"55089" = 1
"55091" = 3
"55093" = 3
"55095" = 4
"55097" = 3
"55099" = 4
"55101" = 5
"55103" = 5
"55105" = 4
"55107" = 9
"55109" = 1
"55111" = 3
"55113" = 8
"55115" = 4
"55117" = 2
"55119" = 4
"55121" = 4
"55123" = 5
"55125" = 5
"55127" = 4
"55129" = 5
"55131" = 1
"55133" = 1
"55135" = 3
"55137" = 5
"55139" = 3
"55141" = 3
"56001" = 9
"56003" = 4
"56005" = 1
"56007" = 4
"56009" = 2
"56011" = 1
"56013" = 4
"56015" = 7
"56017" = 3
"56019" = 2
"56021" = 3
"56023" = 2
"56025" = 2
"56027" = 5
"56029" = 3
"56031" = 3
"56033" = 2
"56035" = 1
"56037" = 2
"56039" = 2
"56041" = 3
"56043" = 3
"56045" = 2
"02201" = 7
"02232" = 5
"02280" = 3
OTHER = 0
;

/* ---------------------------------------------------------------- */
 /* LOW BIRTH WEIGHT                                                 */
 /* ---------------------------------------------------------------- */

 /* ICD-10-CM DIAGNOSIS CODES: */

value $LW500G
"P0501"  =  "1"  /* Newborn light for gestational age, less than 500 grams */
"P0511"  =  "1"  /* Newborn small for gestational age, less than 500 grams */
"P0701"  =  "1"  /* Extremely low birth weight newborn, less than 500 grams */
OTHER = "0" ;

value $LW750G
"P0502"  =  "1"  /* Newborn light for gestational age, 500-749 grams */
"P0512"  =  "1"  /* Newborn small for gestational age, 500-749 grams */
"P0702"  =  "1"  /* Extremely low birth weight newborn, 500-749 grams */
OTHER   = "0";

value $LW1000G
"P0503"  =  "1"  /* Newborn light for gestational age, 750-999 grams */
"P0513"  =  "1"  /* Newborn small for gestational age, 750-999 grams */
"P0703"  =  "1"  /* Extremely low birth weight newborn, 750-999 grams */
OTHER   = "0";

value $LW1250G
"P0504"  =  "1"  /* Newborn light for gestational age, 1000-1249 grams */
"P0514"  =  "1"  /* Newborn small for gestational age, 1000-1249 grams */
"P0714"  =  "1"  /* Other low birth weight newborn, 1000-1249 grams */
OTHER   = "0";

value $LW1500G
"P0505"  =  "1"  /* Newborn light for gestational age, 1250-1499 grams */
"P0515"  =  "1"  /* Newborn small for gestational age, 1250-1499 grams */
"P0715"  =  "1"  /* Other low birth weight newborn, 1250-1499 grams */
OTHER   = "0";

value $LW1750G
"P0506"  =  "1"  /* Newborn light for gestational age, 1500-1749 grams */
"P0516"  =  "1"  /* Newborn small for gestational age, 1500-1749 grams */
"P0716"  =  "1"  /* Other low birth weight newborn, 1500-1749 grams */
OTHER   = "0";

value $LW2000G
"P0507"  =  "1"  /* Newborn light for gestational age, 1750-1999 grams */
"P0517"  =  "1"  /* Newborn small for gestational age, 1750-1999 grams */
"P0717"  =  "1"  /* Other low birth weight newborn, 1750-1999 grams */
OTHER   = "0";

value $LW2500G
"P0508"  =  "1"  /* Newborn light for gestational age, 2000-2499 grams */
"P0518"  =  "1"  /* Newborn small for gestational age, 2000-2499 grams */
"P0718"  =  "1"  /* Other low birth weight newborn, 2000-2499 grams */
OTHER   = "0";

 /* LIVE BIRTH */
 /* ICD-10-CM DIAGNOSIS CODES */

value $LIVEBND
"Z3800"  =  "1"  /* Single liveborn infant, delivered vaginally */
"Z3801"  =  "1"  /* Single liveborn infant, delivered by cesarean */
"Z3830"  =  "1"  /* Twin liveborn infant, delivered vaginally */
"Z3831"  =  "1"  /* Twin liveborn infant, delivered by cesarean */
"Z3861"  =  "1"  /* Triplet liveborn infant, delivered vaginally */
"Z3862"  =  "1"  /* Triplet liveborn infant, delivered by cesarean */
"Z3863"  =  "1"  /* Quadruplet liveborn infant, delivered vaginally */
"Z3864"  =  "1"  /* Quadruplet liveborn infant, delivered by cesarean */
"Z3865"  =  "1"  /* Quintuplet liveborn infant, delivered vaginally */
"Z3866"  =  "1"  /* Quintuplet liveborn infant, delivered by cesarean */
"Z3868"  =  "1"  /* Other multiple liveborn infant, delivered vaginally */
"Z3869"  =  "1"  /* Other multiple liveborn infant, delivered by cesarean */
OTHER   = 0 ;

 /* LIVE BIRTH OUTSIDE HOSPITAL */
 /* ICD-10-CM DIAGNOSIS CODES */
value $LIVEB2D
"Z381"  =  "1"  /* Single liveborn infant, born outside hospital */
"Z384"  =  "1"  /* Twin liveborn infant, born outside hospital */
"Z387"  =  "1"  /* Other multiple liveborn infant, born outside hospital */
OTHER   = 0 ;

 
/* Low Birth Weight (Outcome of Interest) */
 /* ICD-10-CM Diagnosis Codes:              */

value $ACSLBWD
"P0501"  =  "1"  /* Newborn light for gestational age, less than 500 grams */
"P0502"  =  "1"  /* Newborn light for gestational age, 500-749 grams */
"P0503"  =  "1"  /* Newborn light for gestational age, 750-999 grams */
"P0504"  =  "1"  /* Newborn light for gestational age, 1000-1249 grams */
"P0505"  =  "1"  /* Newborn light for gestational age, 1250-1499 grams */
"P0506"  =  "1"  /* Newborn light for gestational age, 1500-1749 grams */
"P0507"  =  "1"  /* Newborn light for gestational age, 1750-1999 grams */
"P0508"  =  "1"  /* Newborn light for gestational age, 2000-2499 grams */
"P0511"  =  "1"  /* Newborn small for gestational age, less than 500 grams */
"P0512"  =  "1"  /* Newborn small for gestational age, 500-749 grams */
"P0513"  =  "1"  /* Newborn small for gestational age, 750-999 grams */
"P0514"  =  "1"  /* Newborn small for gestational age, 1000-1249 grams */
"P0515"  =  "1"  /* Newborn small for gestational age, 1250-1499 grams */
"P0516"  =  "1"  /* Newborn small for gestational age, 1500-1749 grams */
"P0517"  =  "1"  /* Newborn small for gestational age, 1750-1999 grams */
"P0518"  =  "1"  /* Newborn small for gestational age, 2000-2499 grams */
"P0700"  =  "1"  /* Extremely low birth weight newborn, unspecified weight */
"P0701"  =  "1"  /* Extremely low birth weight newborn, less than 500 grams */
"P0702"  =  "1"  /* Extremely low birth weight newborn, 500-749 grams */
"P0703"  =  "1"  /* Extremely low birth weight newborn, 750-999 grams */
"P0710"  =  "1"  /* Other low birth weight newborn, unspecified weight */
"P0714"  =  "1"  /* Other low birth weight newborn, 1000-1249 grams */
"P0715"  =  "1"  /* Other low birth weight newborn, 1250-1499 grams */
"P0716"  =  "1"  /* Other low birth weight newborn, 1500-1749 grams */
"P0717"  =  "1"  /* Other low birth weight newborn, 1750-1999 grams */
"P0718"  =  "1"  /* Other low birth weight newborn, 2000-2499 grams */
OTHER   = 0 ;

run;